# genepass

generating passward randomly!

# Install
`pip install odach`

# Usage

```python
import genepass

genepass.create_random_password()
```

# Option

- strong : DIGITS & CAPITAL_LETTER & SMALL_LETTER
- god : DIGITS & CAPITAL_LETTER & SMALL_LETTER & SYMBOLS
- custom : Under construction